@@ -5,7 +5,7 @@
 
 package JTM::Boilerplate;
 # ABSTRACT: Default Boilerplate for Joelle Maslak's Code
-$JTM::Boilerplate::VERSION = '2.211420';
+$JTM::Boilerplate::VERSION = '2.231930';
 use strict;
 use warnings;
 
@@ -59,7 +59,6 @@ sub import ( $self, $type = 'script' ) {
     # feature->import::into($target, 'refaliasing');
     feature->import::into( $target, 'signatures' );
 
-    feature->import::into( $target, 'switch' );
     feature->import::into( $target, 'unicode_strings' );
     # warnings->unimport::out_of($target, 'experimental::refaliasing');
     warnings->unimport::out_of( $target, 'experimental::signatures' );
@@ -68,9 +67,6 @@ sub import ( $self, $type = 'script' ) {
         warnings->unimport::out_of( $target, 'experimental::postderef' );
     }
 
-    # For "switch" feature
-    warnings->unimport::out_of( $target, 'experimental::smartmatch' );
-
     # For "re 'strict'" feature
     warnings->unimport::out_of( $target, 'experimental::re_strict' );
     re->import( 'strict' );
@@ -113,7 +109,7 @@ JTM::Boilerplate - Default Boilerplate for Joelle Maslak's Code
 
 =head1 VERSION
 
-version 2.211420
+version 2.231930
 
 =head1 SYNOPSIS
 
@@ -144,7 +140,7 @@ Joelle Maslak <jmaslak@antelope.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015-2020 by Joelle Maslak.
+This software is copyright (c) 2015-2023 by Joelle Maslak.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
